#
# spec file for package po4a
#
# Copyright (c) 2017 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           po4a
Version:        0.52
Release:        lp151.2.1
Summary:        Framework to translate documentation and other materials
License:        GPL-2.0
Group:          Development/Tools/Other
Url:            http://po4a.alioth.debian.org/
Source:         https://alioth.debian.org/frs/download.php/file/4229/%{name}-%{version}.tar.gz

BuildRequires:  docbook-xsl-stylesheets
BuildRequires:  libxslt-tools
BuildRequires:  perl-Module-Build >= 0.40
BuildRequires:  perl-SGMLS >= 1.03ii
BuildRequires:  perl-Term-ReadKey
BuildRequires:  perl-Text-WrapI18N
BuildRequires:  perl-Unicode-LineBreak
BuildRequires:  perl-base
BuildRequires:  perl-gettext >= 1.01

# for test suite
BuildRequires:  docbook_4
BuildRequires:  iso_ent
BuildRequires:  opensp
BuildRequires:  perl-HTML-Parser

Requires:       %{name}-lang = %{version}
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildArch:      noarch
%{perl_requires}
%lang_package

%description
Po4a extracts the translatable material from its input in a PO file.
When the PO file is translated, it re-injects the translation in the structure of the document, and generates the translated document.
If a string is not translated (i.e. it was not translated or it is "fuzzy"
because the original document was updated), the original string is used.
This permits to provide always up-to-date documentation.

po4a supports currently the following formats:
  * manpages
  * POD
  * XML (generic, DocBook, XHTML, Dia, Guide, or WML)
  * SGML
  * TeX (generic, LaTeX, or Texinfo)
  * text (simple text files with some formatting, markdown, or AsciiDoc)
  * INI

%prep
%setup -q

%build
perl Build.PL installdirs=vendor
./Build

%install
./Build install destdir=%{buildroot}
%find_lang %{name} --with-man --all-name
rm -f %{buildroot}%{perl_vendorarch}/auto/po4a/.packlist

%check
# requires texlive, which is too heavy for the package
rm t/24-tex.t
./Build test

%clean
rm -rf %{buildroot}

%files
%defattr(644,root,root,755)
%doc COPYING NEWS README* TODO
%attr(755,root,root) %{_bindir}/*
%dir %{perl_vendorlib}/Locale/
%{perl_vendorlib}/Locale/Po4a
%{_mandir}/man[1357]/*

%files lang -f %{name}.lang
%defattr(-,root,root)
%dir %{_mandir}/ca
%dir %{_mandir}/pl
%dir %{_mandir}/pt

%changelog
* Mon Aug 28 2017 elchevive@opensuse.org
- updated to version 0.52
  Core:
  * po4a-translate complains if the input po file is outdated (deb#637288).
  * teach po4a-updatepo about the --porefs options that was already documented.
  * rename --porefs values after msgmerge option's name: noline->file
  and none->never. (deb#775708).
  po4a:
  * New option --no-update to not touch the po files. (deb#599179)
  * Checking po file is fine. Failing if the file does not exist isn't.
  (deb#858934)
  * Check the validity of po files before using them (deb#855431)
  AsciiDoc:
  * Properly deal with item text missing its leading indent.
  * Allow empty attribute lists, by bexelbie.
  * Further bug fixing to handle the git documentation.
  * Fix some bugs, around style macros
  * Correctly handle list literal paragraph
  Man:
  * Add support for the tab(<character>) global option inside .TS/.TE.
  Also tidy up trailing newline handling in text blocks: Since that
  trailing newling must be there, no need to translate it explicitly.
  (deb#847754).
  Text:
  * Add an option to treat Key/Value pairs as verbatim
  * Add a neverwrap option to prevent any wrapping (deb#824753)
  RubyDoc:
  * New module by Francesco Poli (deb#827936)
  Wml:
  * Make title translatable.
  XML:
  * Add an option to escape all quotes, for android.
  * Add an option to not wrap attributes.
* Thu Sep 15 2016 elchevive@opensuse.org
- updated to version 0.48
- Remove BuildRequires if's for older versions (opensuse<=12.1)
  * Major changes in release 0.48
  SGML:
  * Use OpenSP as an underlying engine instead of the deprecated SP
  Thanks to Neil Roeth (deb#809477 and deb#280882)
  Translations:
  * Update Japaneese.
  * Fix formating issue in pt translation
* Fri Aug 28 2015 elchevive@opensuse.org
- updated to version 0.47
  * Major changes in release 0.47
  Man:
  * Fix: don't add supirious lines around \# lines (deb#786642)
  Documentation:
  * Bugfix: poref is a command line option (deb#775707)
  Translations:
  * Update Italian
  Other:
  * Port our regex to Perl 5.22 (deb#788706)
* Thu May 21 2015 elchevive@opensuse.org
- updated to version 0.46
  * Major changes in release 0.46
  Man:
  * Fix handling of preprocessor lines (deb#744366)
  * Fix handling of tbl's textblocks (deb#748601)
  Sgml:
  * Silence a warning about useless greediness modifier (deb#779435)
  Translations:
  * Update Dutch, Vietnamese, and Brazilian Portuguese (deb#782393, deb#776896, and deb#735644)
  Documentation:
  * Update Brazilian Portuguese (deb#735644)
* Wed Nov 19 2014 bwiedemann@suse.com
- fix download link
* Thu Jan 30 2014 elchevive@opensuse.org
- drop po4a-0.44-use-tempfile-correctly.patch
- updated to version 0.45
  po4a:
  * Fix usage of File::Temp::tempfile to allow using Perl >= 5.18.
  Asciidoc:
  * Make it a standalone format.
  Docbook:
  * Make <beginpage> inline.
  Ini:
  * Add key parameter as an automatic comment.  This allows using
  po4a-gettextize on ini files.
  LaTeX:
  * Fix handling of optional parameters in newtheorem command.
  Po:
  * Fix computation of timezone written into PO files.
  Sgml:
  * Fix failing tests with recent Docbook DTD.
* Mon Jun 24 2013 elchevive@opensuse.org
- Add po4a-0.44-use-tempfile-correctly.patch to fix tempfile build
  errors on Perl >-5.18 by replacing 'File::Temp->tempfile' with
  'File::Temp::tempfile'
- Source URL corrected
* Mon Apr 15 2013 idonmez@suse.com
- Add Source URL, see https://en.opensuse.org/SourceUrls
* Sun Jan 27 2013 coolo@suse.com
- do not buildrequire texlive
* Sun Oct 21 2012 elchevive@opensuse.org
- update to version 0.44:
  Fix packaging issues with 0.43
* Fri Oct 19 2012 elchevive@opensuse.org
- update to version 0.43:
  po4a:
  * Add --porefs option to change how file locations are written into
  the POT file (and thus into the PO files also).
  po4a-updatepo po4a Po:
  * Extend the --porefs option, add a new 'counter' value to replace
  line number by an increasing counter.
  An optional ",nowrap" or ",wrap" specifier can be added to tell
  whether file locations are written on a single line or wrapped on
  several lines.  Default is ",nowrap", it will be changed to ",wrap"
  in a future release.
  Man:
  * Make .UR/.UE macros inline.
  * Add macros used in several NetBSD man pages: %%I %%U Brc Bro Lp Lk
  Text:
  * Fix two line titles in AsciiDoc format.
  * Let AsciiDoc format handle many more styles.
  * Add support for automatic comments in AsciiDoc format.
* Thu May 17 2012 elchevive@opensuse.org
- update to version 0.42:
  po4a:
  * Allow adding command-line options after config file.
  Text:
  * Add support for control files.
  msguntypot:
  * Do not remove obsolete entries from PO files.
  documentation translations updates
  * New German translations
  * Updated Spanish translations
  * Updated French translations
  * Updated Japanese translations
  * Updated Polish translations
* Fri Mar 23 2012 elchevive@opensuse.org
- Reflect changes on libxslt package (-tool subpackage created)
* Wed Mar 21 2012 elchevive@opensuse.org
- Add perl_requires and libxslt1
* Mon Feb 13 2012 prusnak@opensuse.org
- spec cleanup
* Wed Jan  5 2011 elchevive@opensuse.org
- enable tests and split -lang package
* Tue Jan  4 2011 elchevive@opensuse.org
- initial packaging
